# Spyder Pomodoro Timer

A very simple pomodoro timer that shows in the status bar.

## Build status

https://github.com/spyder-ide/spyder-boilerplate/actions?query=workflow%3A%22Win+tests%22

[![Win](https://github.com/spyder-ide/spyder-pomodoro-timer/workflows/Win%20tests/badge.svg)](https://github.com/spyder-ide/spyder-pomodoro-timer/actions?query=workflow%3A%22Win+tests%22)
[![Mac](https://github.com/spyder-ide/spyder-pomodoro-timer/workflows/Mac%20tests/badge.svg)](https://github.com/spyder-ide/spyder-pomodoro-timer/actions?query=workflow%3A%22Mac+tests%22)
[![Linux](https://github.com/spyder-ide/spyder-pomodoro-timer/workflows/Linux%20tests/badge.svg)](https://github.com/spyder-ide/spyder-pomodoro-timer/actions?query=workflow%3A%Linux+tests%22)
[![Codecov](https://codecov.io/gh/spyder-ide/spyder-pomodoro-timer/branch/master/graph/badge.svg)](https://codecov.io/gh/spyder-ide/spyder-pomodoro-timer)
[![Crowdin](https://badges.crowdin.net/spyder-pomodoro-timer/localized.svg)](https://crowdin.com/project/spyder-pomodoro-timer)
[![Docs](https://readthedocs.org/projects/spyder-pomodoro-timer/badge/?version=latest)](https://spyder-pomodoro-timer.readthedocs.io/en/latest/?badge=latest)

## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [spyder-ide/spyder5-plugin-cookiecutter](https://github.com/spyder-ide/spyder5-plugin-cookiecutter) project template.
